#include <qapplication.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qfont.h>
#include <qlayout.h>
#include <qstring.h>

#include "painter.h"
#include "turtle.h"


Painter::Painter( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setMinimumSize( 500, 355 );

    QPushButton *quit = new QPushButton( "Quit", this, "quit" );
    quit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );

    turtle = new Turtle( this, "turtle" );
	connect( turtle, SIGNAL(changePos()), SLOT(newPosition( )) );
	connect( turtle, SIGNAL(changeSize()), SLOT(newSize( )) );

    clear = new QPushButton( "Clear", this, "clear" );
    clear->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( clear, SIGNAL(clicked()), turtle, SLOT(clearscreen()) );

    redraw = new QPushButton( "Redraw", this, "redraw" );
    redraw->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( redraw, SIGNAL(clicked()), turtle, SLOT(redraw()) );

    QGridLayout *grid = new QGridLayout( this, 1, 2, 5 ); //2x2, 5 pixel border
    grid->addWidget( turtle, 0, 1 );
    grid->setColStretch( 1, 10 );

    messpos = new QLabel( this, "messagepos"  );
    messpos->setMaximumHeight( 20 );
    messpos->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
    messpos->setBackgroundColor( messpos->colorGroup().base() );
    messpos->setAlignment( AlignCenter );

    messize = new QLabel( this, "message_size"  );
    messize->setMaximumHeight( 20 );
    messize->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
    messize->setBackgroundColor( messpos->colorGroup().base() );
    messize->setAlignment( AlignCenter );

	QVBoxLayout *leftBox = new QVBoxLayout;
	grid->addLayout( leftBox, 0, 0 );
	leftBox->addWidget( quit );
	leftBox->addWidget( clear );
	leftBox->addWidget( redraw );
	leftBox->addWidget( messpos );
	leftBox->addWidget( messize );
}

void Painter::newPosition( )
{
	int mx, my;

	turtle->getPosition( &mx, &my );

    QString s;
	messpos->setText( s.sprintf("%d,%d", mx, my ) );
}

void Painter::newSize( )
{
	int mx, my;

	turtle->getSize( &mx, &my );

    QString s;
	messize->setText( s.sprintf("%d,%d", mx, my ) );
}
